Population in Provinces
=======================

This example demonstrates how to calculate population statistics for provinces in Italy.
It shows how to:

1. Load geospatial data from GeoPackage files using ``geopackage_to_dataframe``
2. Filter data to select specific provinces in Northern Italy
3. Perform a spatial join between provinces and population data using ``spatial_join``
4. Aggregate population data by province using ``spatial_aggregation``


.. toctree::

   /_collections/notebooks/population_in_provinces.ipynb
